@@ -23,10 +23,12 @@ class Rule:
         return [Rule(item) for item in array]
 
     def __init__(self, dict_json: Dict[str, Any]):
+        self.id_: int = dict_json["id"]
         self.order: int = dict_json.get("order", 0)
         self.type: str = dict_json.get("type", "")
         self.exposition: float = dict_json.get("exposition", 0.0)
-        self.experiment_id = dict_json.get("experiment_id", None)
+        self.experiment_id: int = dict_json.get("experimentId", 0)
+        self.respool_time: Optional[int] = dict_json.get("respoolTime", None)
         self.variation_by_exposition: List[
             VariationByExposition
         ] = VariationByExposition.from_array(dict_json.get("variationByExposition", []))
@@ -35,18 +37,21 @@ class Rule:
             Segment(segment) if segment else None
         )
 
-    def get_variation_key(self, hash_double: float) -> Optional[str]:
+    def get_variation(self, hash_double: float) -> Optional[VariationByExposition]:
         """Calculates the variation key for the given hash of visitor"""
         total = 0.0
         for var_by_exp in self.variation_by_exposition:
             total += var_by_exp.exposition
             if total >= hash_double:
-                return var_by_exp.variation_key
+                return var_by_exp
         return None
 
-    def get_variation_id_by_key(self, key: str) -> Optional[int]:
-        """Find the variation id for the given variation key"""
-        var_by_exp = next(
-            (v for v in self.variation_by_exposition if v.variation_key == key), None
-        )
-        return var_by_exp.variation_id if var_by_exp else None
+    @property
+    def is_experimentation(self) -> bool:
+        """Return `true` if rule is `experimentation` type"""
+        return self.type == Rule.Type.EXPERIMENTATION.value
+
+    @property
+    def is_targeted_delivery(self) -> bool:
+        """Return `true` if rule is `targeted delivery` type"""
+        return self.type == Rule.Type.TARGETED_DELIVERY.value
