@@ -43,7 +43,7 @@ def simple_test_view(request):
         "respoolTime": {},
         "siteEnabled": True,
     }
-    client.experiments.append(experiment)
+    client._experiments.append(experiment)
     visitor_code = client.get_visitor_code(request.COOKIES, local_ip)
 
     variation_id = None
